/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.json;

public class ServletConstants {

	public static final String USM_LOGIN = "login";
	public static final String USM_LOGOUT = "logout";
	public static final String USM_GET_CONFIGURATION = "getConfiguration";
	public static final String USM_SET_CONFIGURATION = "setConfiguration";
	public static final String USM_SYNC_INIT = "syncInit";
	public static final String USM_SYNC_ESTIMATE = "syncEstimate";
	public static final String USM_SYNC_UPDATE = "syncUpdate";
	public static final String USM_SET_PUSH_NOTIFICATION = "setPushNotification";
	public static final String USM_READ_DATA = "readData";
	public static final String USM_SEND_MAIL = "sendMail";
	public static final String USM_RESOLVE_RECIPIENTS = "resolveRecipients";
	public static final String USM_MOVE_ITEMS = "moveItems";
	public static final String GET_CACHED_DATA = "getCachedData";
	public static final String USM_PING = "ping";
	public static final String USM_RESOLVE_IDS = "resolveIDs";
	public static final String USM_INVALIDATE_OBJECTS = "invalidateObjects";
	public static final String USM_LOCATE_OBJECTS = "locateObjects";
	public static final String USM_SET_CONFIRMATION_STATUS = "setConfirmationStatus";
    public static final String USM_DOWNLOAD_DATA = "downloadData";
    public static final String USM_UPLOAD_DATA = "uploadData";
    public static final String USM_CLEAR_DATA = "clearData";

	public static final String TEXT_JAVASCRIPT = "text/javascript";
	public static final String UTF_ENCODING_8 = "UTF-8";

	public static final String PROTOCOL = "JSON";
	
	public static final String USM_JSON_CONTENT_TYPE = TEXT_JAVASCRIPT + "; charset=UTF-8";
}
